@@ -16,7 +16,9 @@ namespace Tomboy
 {
 	public class GnomeApplication : INativeApplication
 	{
+#if PANEL_APPLET
 		private Gnome.Program program;
+#endif
 		private static string confDir;
 		private static string dataDir;
 		private static string cacheDir;
@@ -70,10 +72,12 @@ namespace Tomboy
 			}
 
 			Gtk.Application.Init ();
+#if PANEL_APPLET
 			program = new Gnome.Program (display_name,
 			                             Defines.VERSION,
 			                             Gnome.Modules.UI,
 			                             args);
+#endif
 		}
 
 		public void RegisterSessionManagerRestart (string executable_path,
@@ -102,7 +106,11 @@ namespace Tomboy
 
 		public void StartMainLoop ()
 		{
+#if PANEL_APPLET
 			program.Run ();
+#else
+			Gtk.Application.Run ();
+#endif
 		}
 
 		[DllImport("libc")]
@@ -173,10 +181,27 @@ namespace Tomboy
 		{
 			GtkBeans.Global.ShowUri (screen, url);
 		}
+
+		[DllImport ("glib-2.0.dll")]
+		static extern IntPtr g_get_language_names ();
 		
-		public void DisplayHelp (string help_uri, Gdk.Screen screen)
+		public void DisplayHelp (string project, string page, Gdk.Screen screen)
 		{
-			GtkBeans.Global.ShowUri (screen, help_uri);
+			string helpUrl = string.Format("http://library.gnome.org/users/{0}/", project);
+
+			var langsPtr = g_get_language_names ();
+			var langs = GLib.Marshaller.NullTermPtrToStringArray (langsPtr, false);
+			var baseHelpDir = Path.Combine (Path.Combine (Defines.DATADIR, "gnome/help"), project);
+			if (Directory.Exists (baseHelpDir)) {
+				foreach (var lang in langs) {
+					var langHelpDir = Path.Combine (baseHelpDir, lang);
+					if (Directory.Exists (langHelpDir))
+						// TODO:Support page
+						helpUrl = String.Format ("ghelp://{0}", langHelpDir);
+				}
+			}
+
+			OpenUrl (helpUrl, screen);
 		}
 		
 		public string DataDirectory {
