@@ -494,7 +494,7 @@ namespace Tomboy
 			if (!save_needed)
 				return;
 
-			Logger.Log ("Saving '{0}'...", data.Data.Title);
+			Logger.Debug ("Saving '{0}'...", data.Data.Title);
 
 			try {
 				NoteArchiver.Write (filepath, data.GetDataSynchronized ());
@@ -628,7 +628,7 @@ namespace Tomboy
 			} catch (Exception e) {
 				// FIXME: Present a nice dialog here that interprets the
 				// error message correctly.
-				Logger.Log ("Error while saving: {0}", e);
+				Logger.Error ("Error while saving: {0}", e);
 			}
 		}
 
@@ -864,7 +864,7 @@ namespace Tomboy
 			}
 			set {
 				if (buffer != null) {
-					buffer.SetText("");
+					buffer.Text = string.Empty;
 					NoteBufferArchiver.Deserialize (buffer, value);
 				} else
 					data.Text = value;
@@ -896,63 +896,60 @@ namespace Tomboy
 			xmlDoc.LoadXml (foreignNoteXml);
 			xmlDoc = null;
 
-			StringReader reader = new StringReader (foreignNoteXml);
-			XmlTextReader xml = new XmlTextReader (reader);
-			xml.Namespaces = false;
-
 			// Remove tags now, since a note with no tags has
 			// no "tags" element in the XML
 			List<Tag> newTags = new List<Tag> ();
-			DateTime date;
 
-			while (xml.Read ()) {
-				switch (xml.NodeType) {
-				case XmlNodeType.Element:
-					switch (xml.Name) {
-					case "title":
-						Title = xml.ReadString ();
-						break;
-					case "text":
-						XmlContent = xml.ReadInnerXml ();
-						break;
-					case "last-change-date":
-						if (DateTime.TryParse (xml.ReadString (), out date))
-							data.Data.ChangeDate = date;
-						else
-							data.Data.ChangeDate = DateTime.Now;
-						break;
-					case "last-metadata-change-date":
-						if (DateTime.TryParse (xml.ReadString (), out date))
-							data.Data.MetadataChangeDate = date;
-						else
-							data.Data.MetadataChangeDate = DateTime.Now;
-						break;
-					case "create-date":
-						if (DateTime.TryParse (xml.ReadString (), out date))
-							data.Data.CreateDate = date;
-						else
-							data.Data.CreateDate = DateTime.Now;
-						break;
-					case "tags":
-						XmlDocument doc = new XmlDocument ();
-						List<string> tag_strings = ParseTags (doc.ReadNode (xml.ReadSubtree ()));
-						foreach (string tag_str in tag_strings) {
-							Tag tag = TagManager.GetOrCreateTag (tag_str);
-							newTags.Add (tag);
+			using (var xml = new XmlTextReader (new StringReader (foreignNoteXml)) {Namespaces = false}) {
+				DateTime date;
+	
+				while (xml.Read ()) {
+					switch (xml.NodeType) {
+					case XmlNodeType.Element:
+						switch (xml.Name) {
+						case "title":
+							Title = xml.ReadString ();
+							break;
+						case "text":
+							XmlContent = xml.ReadInnerXml ();
+							break;
+						case "last-change-date":
+							if (DateTime.TryParse (xml.ReadString (), out date))
+								data.Data.ChangeDate = date;
+							else
+								data.Data.ChangeDate = DateTime.Now;
+							break;
+						case "last-metadata-change-date":
+							if (DateTime.TryParse (xml.ReadString (), out date))
+								data.Data.MetadataChangeDate = date;
+							else
+								data.Data.MetadataChangeDate = DateTime.Now;
+							break;
+						case "create-date":
+							if (DateTime.TryParse (xml.ReadString (), out date))
+								data.Data.CreateDate = date;
+							else
+								data.Data.CreateDate = DateTime.Now;
+							break;
+						case "tags":
+							XmlDocument doc = new XmlDocument ();
+							List<string> tag_strings = ParseTags (doc.ReadNode (xml.ReadSubtree ()));
+							foreach (string tag_str in tag_strings) {
+								Tag tag = TagManager.GetOrCreateTag (tag_str);
+								newTags.Add (tag);
+							}
+							break;
+						case "open-on-startup":
+							bool isStartup;
+							if (bool.TryParse (xml.ReadString (), out isStartup))
+								IsOpenOnStartup = isStartup;
+							break;
 						}
 						break;
-					case "open-on-startup":
-						bool isStartup;
-						if (bool.TryParse (xml.ReadString (), out isStartup))
-							IsOpenOnStartup = isStartup;
-						break;
 					}
-					break;
 				}
 			}
 
-			xml.Close ();
-
 			foreach (Tag oldTag in Tags)
 				if (!newTags.Contains (oldTag))
 				    RemoveTag (oldTag);
@@ -988,9 +985,9 @@ namespace Tomboy
 			}
 			set {
 				if (buffer != null)
-					buffer.SetText (value);
+					buffer.Text = value;
 				else
-					Logger.Log ("Setting text content for closed notes not supported");
+					Logger.Error ("Setting text content for closed notes not supported");
 			}
 
 		}
@@ -1065,7 +1062,7 @@ namespace Tomboy
 		{
 			get {
 				if (buffer == null) {
-					Logger.Log ("Creating Buffer for '{0}'...",
+					Logger.Debug ("Creating Buffer for '{0}'...",
 					data.Data.Title);
 
 					buffer = new NoteBuffer (TagTable, this);
@@ -1267,24 +1264,18 @@ namespace Tomboy
 
 		public virtual NoteData ReadFile (string read_file, string uri)
 		{
-			StreamReader reader = new StreamReader (read_file,
-			                                        System.Text.Encoding.UTF8);
-			XmlTextReader xml = new XmlTextReader (reader);
-			xml.Namespaces = false;
-
+			NoteData data;
 			string version;
-			NoteData data = Read (xml, uri, out version);
+			using (var xml = new XmlTextReader (new StreamReader (read_file, System.Text.Encoding.UTF8)) {Namespaces = false})
+				data = Read (xml, uri, out version);
 
 			if (version != NoteArchiver.CURRENT_VERSION) {
 				// Note has old format, so rewrite it.  No need
 				// to reread, since we are not adding anything.
-				Logger.Log ("Updating note XML to newest format...");
+				Logger.Info ("Updating note XML to newest format...");
 				NoteArchiver.Write (read_file, data);
 			}
 
-			reader.Close ();
-			xml.Close ();
-
 			return data;
 		}
 
@@ -1379,9 +1370,8 @@ namespace Tomboy
 		public static string WriteString(NoteData note)
 		{
 			StringWriter str = new StringWriter ();
-			XmlWriter xml = XmlWriter.Create (str, XmlEncoder.DocumentSettings);
-			Instance.Write (xml, note);
-			xml.Close ();
+			using (var xml = XmlWriter.Create (str, XmlEncoder.DocumentSettings))
+				Instance.Write (xml, note);
 			str.Flush();
 			return str.ToString ();
 		}
@@ -1395,9 +1385,8 @@ namespace Tomboy
 		{
 			string tmp_file = write_file + ".tmp";
 
-			XmlWriter xml = XmlWriter.Create (tmp_file, XmlEncoder.DocumentSettings);
-			Write (xml, note);
-			xml.Close ();
+			using (var xml = XmlWriter.Create (tmp_file, XmlEncoder.DocumentSettings))
+				Write (xml, note);
 
 			if (File.Exists (write_file)) {
 				string backup_path = write_file + "~";
@@ -1425,9 +1414,8 @@ namespace Tomboy
 
 		public void WriteFile (TextWriter writer, NoteData note)
 		{
-			XmlWriter xml = XmlWriter.Create (writer, XmlEncoder.DocumentSettings);
-			Write (xml, note);
-			xml.Close ();
+			using (var xml = XmlWriter.Create (writer, XmlEncoder.DocumentSettings))
+				Write (xml, note);
 		}
 
 		void Write (XmlWriter xml, NoteData note)
@@ -1573,46 +1561,54 @@ namespace Tomboy
 		public static void ShowDeletionDialog (List<Note> notes, Gtk.Window parent)
 		{
 			string message;
+
+			if ((bool) Preferences.Get (Preferences.ENABLE_DELETE_CONFIRM)) {
+				// show confirmation dialog
+				if (notes.Count == 1)
+					message = Catalog.GetString ("Really delete this note?");
+				else
+					message = string.Format (Catalog.GetPluralString (
+						"Really delete this {0} note?",
+						"Really delete these {0} notes?",
+						notes.Count), notes.Count);
 			
-			if (notes.Count == 1)
-				message = Catalog.GetString ("Really delete this note?");
-			else
-				message = string.Format (Catalog.GetPluralString (
-					"Really delete this {0} note?",
-					"Really delete these {0} notes?",
-					notes.Count), notes.Count);
-			
-			HIGMessageDialog dialog =
-			        new HIGMessageDialog (
-			        parent,
-			        Gtk.DialogFlags.DestroyWithParent,
-			        Gtk.MessageType.Question,
-			        Gtk.ButtonsType.None,
-			        message,
-			        Catalog.GetString ("If you delete a note it is " +
+				HIGMessageDialog dialog =
+				        new HIGMessageDialog (
+				        parent,
+				        Gtk.DialogFlags.DestroyWithParent,
+				        Gtk.MessageType.Question,
+				        Gtk.ButtonsType.None,
+				        message,
+				        Catalog.GetString ("If you delete a note it is " +
 			                           "permanently lost."));
 
-			Gtk.Button button;
+				Gtk.Button button;
 
-			button = new Gtk.Button (Gtk.Stock.Cancel);
-			button.CanDefault = true;
-			button.Show ();
-			dialog.AddActionWidget (button, Gtk.ResponseType.Cancel);
-			dialog.DefaultResponse = Gtk.ResponseType.Cancel;
+				button = new Gtk.Button (Gtk.Stock.Cancel);
+				button.CanDefault = true;
+				button.Show ();
+				dialog.AddActionWidget (button, Gtk.ResponseType.Cancel);
+				dialog.DefaultResponse = Gtk.ResponseType.Cancel;
 
-			button = new Gtk.Button (Gtk.Stock.Delete);
-			button.CanDefault = true;
-			button.Show ();
-			dialog.AddActionWidget (button, 666);
+				button = new Gtk.Button (Gtk.Stock.Delete);
+				button.CanDefault = true;
+				button.Show ();
+				dialog.AddActionWidget (button, 666);
 
-			int result = dialog.Run ();
-			if (result == 666) {
+				int result = dialog.Run ();
+				if (result == 666) {
+					foreach (Note note in notes) {
+						note.Manager.Delete (note);
+					}
+				}
+
+				dialog.Destroy();
+			} else {
+				// no confirmation dialog, just delete
 				foreach (Note note in notes) {
 					note.Manager.Delete (note);
 				}
 			}
-
-			dialog.Destroy();
 		}
 		
 		public static void ShowIOErrorDialog (Gtk.Window parent)
